.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT

.. _canary-gitlab:

canary_gitlab
=============

The `canary_gitlab <https://github.com/sandialabs/canary/tree/main/src/canary_gitlab>`_ plugin extends `canary <https://github.com/sandialabs/canary>`_ to generate and post reports to GitLab.

Installation
------------

At this time, ``canary_gitlab`` is installed with ``canary``::

   pip install canary-wm

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   mr_report
